@@ -7,7 +7,7 @@ Attean::API::Binding - Name to term bindings
 
 =head1 VERSION
 
-This document describes Attean::API::Binding version 0.015
+This document describes Attean::API::Binding version 0.016
 
 =head1 DESCRIPTION
 
@@ -71,7 +71,7 @@ otherwise.
 
 use Type::Tiny::Role;
 
-package Attean::API::Binding 0.015 {
+package Attean::API::Binding 0.016 {
 	use Moo::Role;
 	use Scalar::Util qw(blessed);
 	use List::MoreUtils qw(zip);
@@ -173,7 +173,7 @@ C<< $binding >>.
 	}
 }
 
-package Attean::API::TripleOrQuadPattern 0.015 {
+package Attean::API::TripleOrQuadPattern 0.016 {
 	use Encode qw(encode);
 	use List::MoreUtils qw(zip);
 	use Scalar::Util qw(blessed);
@@ -263,16 +263,23 @@ parsed from C<< $string >> in SPARQL syntax.
 
 	sub parse {
 		my $self	= shift;
+		my $class	= ref($self) || $self;
 		my $string	= shift;
 		my $bytes	= encode('UTF-8', $string, Encode::FB_CROAK);
 		my $parser	= Attean->get_parser('SPARQL')->new(@_);
 		my @values	= $parser->parse_nodes($bytes);
 		my @keys	= $self->variables;
+		
+		my $f	= scalar(@values);
+		my $e	= scalar(@keys);
+		unless ($e == $f) {
+			die "${class}->parse found wrong number of nodes (found $f but expecting $e)";
+		}
 		return $self->new(zip @keys, @values);
 	}
 }
 
-package Attean::API::TripleOrQuad 0.015 {
+package Attean::API::TripleOrQuad 0.016 {
 	use Moo::Role;
 	use List::MoreUtils qw(any);
 	use Carp;
@@ -286,7 +293,7 @@ package Attean::API::TripleOrQuad 0.015 {
 	}
 }
 
-package Attean::API::TriplePattern 0.015 {
+package Attean::API::TriplePattern 0.016 {
 	use Moo::Role;
 	use List::MoreUtils qw(zip);
 	use Scalar::Util qw(blessed);
@@ -338,7 +345,7 @@ package Attean::API::TriplePattern 0.015 {
 	with 'Attean::API::TripleOrQuadPattern', 'Attean::API::Binding';
 }
 
-package Attean::API::Triple 0.015 {
+package Attean::API::Triple 0.016 {
 	use Moo::Role;
 	
 	if ($ENV{ATTEAN_TYPECHECK}) {
@@ -373,7 +380,7 @@ package Attean::API::Triple 0.015 {
 	with 'Attean::API::TriplePattern', 'Attean::API::TripleOrQuad', 'Attean::API::Binding';
 }
 
-package Attean::API::QuadPattern 0.015 {
+package Attean::API::QuadPattern 0.016 {
 	use Scalar::Util qw(blessed);
 	use List::MoreUtils qw(zip);
 	use Moo::Role;
@@ -430,7 +437,7 @@ package Attean::API::QuadPattern 0.015 {
 	with 'Attean::API::TripleOrQuadPattern', 'Attean::API::Binding';
 }
 
-package Attean::API::Quad 0.015 {
+package Attean::API::Quad 0.016 {
 	use Moo::Role;
 	
 	if ($ENV{ATTEAN_TYPECHECK}) {
@@ -457,7 +464,7 @@ package Attean::API::Quad 0.015 {
 }
 
 
-package Attean::API::Result 0.015 {
+package Attean::API::Result 0.016 {
 	use Moo::Role;
 	use Scalar::Util qw(refaddr);
 	use Types::Standard qw(HashRef);
@@ -503,6 +510,13 @@ package Attean::API::Result 0.015 {
 		return $joined;
 	}
 	
+=item C<< project( @keys ) >>
+
+Returns a new L<Attean::Result> binding which contains variable-value mappings
+from the invocant for every variable name in C<< @keys >>.
+
+=cut
+
 	sub project {
 		my $self	= shift;
 		my @vars	= @_;
@@ -513,7 +527,7 @@ package Attean::API::Result 0.015 {
 		}
 		return Attean::Result->new( bindings => \%bindings );
 	}
-	
+
 	sub project_complement {
 		my $self	= shift;
 		my %vars	= map { $_ => 1 } @_;
