@@ -7,7 +7,7 @@ Attean::API::Query - Utility package defining query-related roles
 
 =head1 VERSION
 
-This document describes Attean::API::Query version 0.014
+This document describes Attean::API::Query version 0.016
 
 =head1 SYNOPSIS
 
@@ -24,7 +24,7 @@ This is a utility package for defining query-related roles:
 
 =cut
 
-package Attean::API::DirectedAcyclicGraph 0.014 {
+package Attean::API::DirectedAcyclicGraph 0.016 {
 	use Moo::Role;
 	use Scalar::Util qw(refaddr);
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -149,10 +149,11 @@ package Attean::API::DirectedAcyclicGraph 0.014 {
 	}
 }
 
-package Attean::API::SPARQLSerializable 0.014 {
+package Attean::API::SPARQLSerializable 0.016 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo::Role;
+	use Encode qw(decode_utf8);
 	use Attean::API::Iterator;
 	use Attean::API::Serializer;
 	use AtteanX::Serializer::SPARQL;
@@ -165,7 +166,7 @@ package Attean::API::SPARQLSerializable 0.014 {
 		my $s		= AtteanX::Serializer::SPARQL->new();
 		my $i		= $self->sparql_tokens;
 		my $bytes	= $s->serialize_iter_to_bytes($i);
-		return $bytes;
+		return decode_utf8($bytes);
 	}
 	
 	sub sparql_subtokens {
@@ -401,7 +402,7 @@ package Attean::API::SPARQLSerializable 0.014 {
 	}
 }
 
-package Attean::API::SPARQLQuerySerializable 0.014 {
+package Attean::API::SPARQLQuerySerializable 0.016 {
 	use Moo::Role;
 	use namespace::clean;
 	with 'Attean::API::SPARQLSerializable';
@@ -416,7 +417,7 @@ package Attean::API::SPARQLQuerySerializable 0.014 {
 
 =cut
 
-package Attean::API::Algebra 0.014 {
+package Attean::API::Algebra 0.016 {
 	use Moo::Role;
 
 	with 'Attean::API::SPARQLSerializable';
@@ -493,7 +494,7 @@ package Attean::API::Algebra 0.014 {
 
 =cut
 
-package Attean::API::QueryTree 0.014 {
+package Attean::API::QueryTree 0.016 {
 	use Moo::Role;
 	with 'Attean::API::DirectedAcyclicGraph';
 }
@@ -502,7 +503,7 @@ package Attean::API::QueryTree 0.014 {
 
 =cut
 
-package Attean::API::NullaryQueryTree 0.014 {
+package Attean::API::NullaryQueryTree 0.016 {
 	use Moo::Role;
 	sub arity { return 0 }
 	with 'Attean::API::QueryTree';
@@ -512,7 +513,7 @@ package Attean::API::NullaryQueryTree 0.014 {
 
 =cut
 
-package Attean::API::UnaryQueryTree 0.014 {
+package Attean::API::UnaryQueryTree 0.016 {
 	use Moo::Role;
 	sub arity { return 1 }
 	with 'Attean::API::QueryTree';
@@ -527,7 +528,7 @@ package Attean::API::UnaryQueryTree 0.014 {
 
 =cut
 
-package Attean::API::BinaryQueryTree 0.014 {
+package Attean::API::BinaryQueryTree 0.016 {
 	use Moo::Role;
 	sub arity { return 2 }
 	with 'Attean::API::QueryTree';
@@ -537,7 +538,7 @@ package Attean::API::BinaryQueryTree 0.014 {
 
 =cut
 
-package Attean::API::PropertyPath 0.014 {
+package Attean::API::PropertyPath 0.016 {
 	use Moo::Role;
 	with 'Attean::API::QueryTree';
 	requires 'as_string';
@@ -548,7 +549,7 @@ package Attean::API::PropertyPath 0.014 {
 
 =cut
 
-package Attean::API::UnaryPropertyPath 0.014 {
+package Attean::API::UnaryPropertyPath 0.016 {
 	use Moo::Role;
 	use Types::Standard qw(ConsumerOf);
 	use namespace::clean;
@@ -578,7 +579,7 @@ package Attean::API::UnaryPropertyPath 0.014 {
 
 =cut
 
-package Attean::API::NaryPropertyPath 0.014 {
+package Attean::API::NaryPropertyPath 0.016 {
 	use Moo::Role;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -605,7 +606,7 @@ package Attean::API::NaryPropertyPath 0.014 {
 
 =cut
 
-package Attean::API::UnionScopeVariables 0.014 {
+package Attean::API::UnionScopeVariables 0.016 {
 	use Moo::Role;
 	sub in_scope_variables {
 		my $self	= shift;
@@ -621,7 +622,7 @@ package Attean::API::UnionScopeVariables 0.014 {
 
 =cut
 
-package Attean::API::IntersectionScopeVariables 0.014 {
+package Attean::API::IntersectionScopeVariables 0.016 {
 	use Moo::Role;
 	sub in_scope_variables {
 		my $self	= shift;
