@@ -7,7 +7,7 @@ Attean::QueryPlanner - Query planner
 
 =head1 VERSION
 
-This document describes Attean::QueryPlanner version 0.015
+This document describes Attean::QueryPlanner version 0.016
 
 =head1 SYNOPSIS
 
@@ -17,7 +17,9 @@ This document describes Attean::QueryPlanner version 0.015
   my $default_graphs = [ Attean::IRI->new('http://example.org/') ];
   my $plan = $planner->plan_for_algebra( $algebra, $model, $default_graphs );
   my $iter = $plan->evaluate($model);
-  my $iter = $e->evaluate( $model );
+  while (my $result = $iter->next()) {
+    say $result->as_string;
+  }
 
 =head1 DESCRIPTION
 
@@ -34,7 +36,7 @@ use Attean::Algebra;
 use Attean::Plan;
 use Attean::Expression;
 
-package Attean::QueryPlanner 0.015 {
+package Attean::QueryPlanner 0.016 {
 	use Moo;
 	use Encode qw(encode);
 	use Attean::RDF;
@@ -104,7 +106,7 @@ the supplied C<< $active_graph >>.
 		my %args			= @_;
 		
 		if ($model->does('Attean::API::CostPlanner')) {
-			my @plans	= $model->plans_for_algebra($algebra, $model, $active_graphs, $default_graphs, %args);
+			my @plans	= $model->plans_for_algebra($algebra, $self, $active_graphs, $default_graphs, %args);
 			if (@plans) {
 				return @plans; # trust that the model knows better than us what plans are best
 			} else {
