@@ -7,7 +7,7 @@ Attean::TermMap - Mapping terms to new terms
 
 =head1 VERSION
 
-This document describes Attean::TermMap version 0.015
+This document describes Attean::TermMap version 0.016
 
 =head1 SYNOPSIS
 
@@ -42,7 +42,7 @@ term objects.
 
 =cut
 
-package Attean::TermMap 0.015 {
+package Attean::TermMap 0.016 {
 	use Moo;
 	use Types::Standard qw(CodeRef);
 	use Attean::API::Binding;
@@ -73,7 +73,7 @@ L<Attean::API::Literal> values.
 		my %map;
 		return $class->new(mapper => sub {
 			my $term	= shift;
-			return $term unless ($term->does('Attean::API::Literal') and $term->datatype);
+			return $term unless ($term->does('Attean::API::Literal'));
 			
 			if ($term->does('Attean::API::NumericLiteral')) {
 				return $term->canonicalized_term;
